@@ -531,6 +531,8 @@ unsafe extern "C" fn completion_provider_populate_async<T: CompletionProviderImp
 ) {
     let instance = &*(ptr as *mut T::Instance);
     let imp = instance.imp();
+    let wrap: CompletionProvider = from_glib_none(ptr);
+
     let context: CompletionContext = from_glib_none(context);
     let cancellable: Option<gio::Cancellable> = from_glib_none(cancellable_ptr);
 
@@ -547,7 +549,7 @@ unsafe extern "C" fn completion_provider_populate_async<T: CompletionProviderImp
         callback.unwrap()(source_object, result, user_data)
     };
 
-    let t = gio::LocalTask::new(None, cancellable.as_ref(), closure);
+    let t = gio::LocalTask::new(Some(&wrap), cancellable.as_ref(), closure);
 
     glib::MainContext::default().spawn_local(async move {
         let res = imp.populate_future(&context).await;
